@@ -2,8 +2,6 @@ prefix="/usr"
 datadir="/usr/share"
 localedir=datadir+"/locale"
 pkgdatadir="/usr/share/mozo"
-libdir="/usr/lib"
-libexecdir="/usr/libexec"
 PACKAGE="mozo"
-VERSION="1.20.2"
+VERSION="1.22.0"
 GETTEXT_PACKAGE="mozo"
